@@ -14,7 +14,10 @@ use Test::Spec qw(*TODO $Debug :constants);
 use Test::Spec::Example;
 use Test::Spec::TodoExample;
 
-our $_StackDepth = 0;
+our @CARP_NOT = ();
+
+my $_StackDepth = 0;
+my $_AroundStackDepth = 1;
 
 sub new {
   my $class = shift;
@@ -124,6 +127,11 @@ sub after_blocks {
   return $self->{_after_blocks} ||= [];
 }
 
+sub around_blocks {
+  my $self = shift;
+  return $self->{_around_blocks} ||= [];
+}
+
 sub tests {
   my $self = shift;
   return $self->{_tests} ||= [];
@@ -375,18 +383,19 @@ sub _run_on_leave {
 # for giving individual tests mortal, anonymous contexts that are used for
 # mocking/stubbing hooks.
 sub _in_anonymous_context {
-  my ($self,$code) = @_;
+  my ($self,$code,$example) = @_;
   my $context = Test::Spec::Context->new;
   $context->name('');
   $context->parent($self);
   $context->class($self->class);
-  $context->contextualize($code);
+  $context->contextualize($code, $example);
 }
 
-# Runs $code within a context (specifically, having been wrapped with
-# on_enter/on_leave setup and teardown).
+# Runs $code within a context (specifically, having been wrapped
+#  with on_enter/on_leave setup and teardown,
+#  and with around blocks).
 sub contextualize {
-  my ($self,$code) = @_;
+  my ($self,$code,$example) = @_;
   local $Test::Spec::_Current_Context = $self;
   local $self->{_has_run_on_enter} = {};
   local $self->{_has_run_on_leave} = {};
@@ -397,7 +406,9 @@ sub contextualize {
   push @errs, $@ if $@;
 
   if (not @errs) {
-    eval { $code->() };
+    $code = $self->wrap_code_with_around_blocks($code,$example);
+
+    eval { $code->($example) };
     push @errs, $@ if $@;
   }
 
@@ -422,6 +433,46 @@ sub contextualize {
   return;
 }
 
+# Wraps $code within a context with around blocks.
+sub wrap_code_with_around_blocks {
+  my ($self,$code,$example) = @_;
+  for (@{ $self->around_blocks }) {
+    $code = $self->wrap_code_with_around_block($code,$_,$example);
+  }
+  return $code;
+}
+
+# Wraps $code within a context with around block.
+sub wrap_code_with_around_block {
+  my ($self,$inner_code,$block,$example) = @_;
+
+  my $this = $self;
+  Scalar::Util::weaken($this);
+
+  return sub {
+    my $yield_ok = 0;
+    local $Test::Spec::Yield = sub {
+      $yield_ok = 1;
+      $inner_code->($example);
+    };
+    $this && $this->_debug(sub {
+      printf STDERR "%s[around CODE %s] %s {\n", '__' x $_AroundStackDepth, $self->_debug_name, "$block";
+      $_AroundStackDepth++;
+    });
+
+    $block->{code}->($example);
+    
+    $this && $this->_debug(sub {
+      $_AroundStackDepth--;
+      printf STDERR "%s[/around CODE %s] %s }\n", '__' x $_AroundStackDepth, $self->_debug_name, "$block";
+    });
+    unless ($yield_ok) {
+      local @CARP_NOT = qw( Test::Spec Test::Spec::Example );
+      Carp::croak "around CODE doesn't call yield";
+    }
+  };
+}
+
 #
 # Copyright (c) 2010-2011 by Informatics Corporation of America.
 # 
