@@ -7,6 +7,8 @@
 ########################################################################
 
 use Test::Spec;
+use FindBin qw($Bin);
+BEGIN { require "$Bin/test_helper.pl" };
 
 $undefined_variable_violates_strict_mode_and_test_should_not_compile;
 
